From aa78fde6a92f66b84d626e114d8b54a5fb6ece0c Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Wed, 14 Nov 2012 07:19:43 -0500
Subject: [PATCH] - Added function for IPv6 prefixes in multiserver mirror setups to nginx plugin.

---
 interface/web/help/support_message_edit.php |   18 +++++++++++++-----
 1 files changed, 13 insertions(+), 5 deletions(-)

diff --git a/interface/web/help/support_message_edit.php b/interface/web/help/support_message_edit.php
index a36b5db..c6e992f 100644
--- a/interface/web/help/support_message_edit.php
+++ b/interface/web/help/support_message_edit.php
@@ -7,11 +7,8 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-//* Checking module permissions
-if(!stristr($_SESSION['s']['user']['modules'],'help')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('help');
 
 //* Loading the templating and form classes
 $app->uses('tpl,tform,tform_actions');
@@ -52,6 +49,17 @@
 		//* call the onShow function of the parent class
 		parent::onShow();
 	}
+	
+	function onAfterInsert() 
+    {
+		global $app, $conf;
+		
+		if($_SESSION['s']['user']['typ'] == 'admin') {
+			$app->db->query("UPDATE support_message SET sys_userid = ".$this->dataRecord['recipient_id']." WHERE support_message_id = ".$this->id);
+		}
+		
+	}
+	
 }
 
 //* Create the new page object

--
Gitblit v1.9.1